==> kapla-2.1.2.tgz: package/lib/events/Handler.js <==
function _toConsumableArray(arr) { return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _nonIterableSpread(); }

function _nonIterableSpread() { throw new TypeError("Invalid attempt to spread non-iterable instance"); }

function _iterableToArray(iter) { if (Symbol.iterator in Object(iter) || Object.prototype.toString.call(iter) === "[object Arguments]") return Array.from(iter); }

function _arrayWithoutHoles(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = new Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } }

function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance"); }

function _iterableToArrayLimit(arr, i) { var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

import detectIt from 'detect-it';
import { ucfirst, lcfirst, $parent } from '../helpers';
import { customEvents, mixedEvents, passiveEvents, subscribers } from '../events';
export var Handler =
/*#__PURE__*/
function () {
  _createClass(Handler, null, [{
    key: "events",
    get: function get() {
      return this._events || Object.defineProperty(this, '_events', {
        value: Object.getOwnPropertyNames(this.prototype).filter(function (type) {
          return /^on/.test(type);
        }).map(function (type) {
          return lcfirst(type.slice(2));
        })
      })._events;
    }
  }]);

  function Handler(context) {
    _classCallCheck(this, Handler);

    this.context = context;
    this.plugins = context.module.application.plugins;
  }

  _createClass(Handler, [{
    key: "getMethod",
    value: function getMethod(eventName) {
      var name = eventName; // If part of mixed event, look for mixed event method
      // ex: mousenter -> onEnter ?

      if (mixedEvents.hasValue(eventName) && this.constructor.events.includes(mixedEvents.getKeysForValue(eventName)[0])) {
        var _mixedEvents$getKeysF = mixedEvents.getKeysForValue(eventName);

        var _mixedEvents$getKeysF2 = _slicedToArray(_mixedEvents$getKeysF, 1);

        name = _mixedEvents$getKeysF2[0];
      }

      var type = ucfirst(name);
      return "on".concat(type);
    }
  }, {
    key: "getCustomOptions",
    value: function getCustomOptions(type) {
      return this["options".concat(ucfirst(type))] || false;
    }
  }, {
    key: "getCategory",
    value: function getCategory(type) {
      // Custom event
      if (customEvents.getScope(type)) {
        return 'custom';
      } // Mixed event


      if (mixedEvents.hasKey(type)) {
        return 'mixed';
      } // Native event


      if (this[this.getMethod(type)]) {
        return 'native';
      }

      return false;
    }
  }, {
    key: "_bindEvent",
    value: function _bindEvent(type) {
      var _this = this;

      var category = this.getCategory(type);

      if (!category) {
        this.context.handleError(new Error(), "Unknown event type [".concat(type, "]"));
      }

      switch (category) {
        case 'custom':
          customEvents.bind(type, this, this.getCustomOptions(type));
          break;

        case 'mixed':
          mixedEvents.getValuesForKey(type).forEach(function (mixed) {
            _this.context.element.addEventListener(mixed, _this, Handler.getOptions(mixed));
          });
          break;

        case 'native':
        default:
          this.context.element.addEventListener(type, this, Handler.getOptions(type));
          break;
      }
    }
  }, {
    key: "_unbindEvent",
    value: function _unbindEvent(type) {
      var _this2 = this;

      var category = this.getCategory(type);

      if (!category) {
        this.context.handleError(new Error(), "Unknown event type [".concat(type, "]"));
      }

      switch (category) {
        case 'custom':
          customEvents.unbind(type, this);
          break;

        case 'mixed':
          mixedEvents.getValuesForKey(type).forEach(function (mixed) {
            _this2.context.element.removeEventListener(mixed, _this2, Handler.getOptions(mixed));
          });
          break;

        case 'native':
        default:
          this.context.element.removeEventListener(type, this, Handler.getOptions(type));
          break;
      }
    }
  }, {
    key: "handleEvent",
    value: function handleEvent(e) {
      var _this3 = this;

      // Get correct type (if mixed event) to check for delegate
      var type = mixedEvents.getKeysForValue(e.type)[0] || e.type;
      var delegate = this["delegate".concat(ucfirst(type))];

      if (delegate) {
        var hasMatch = false;
        var targetElement = null;

        if (typeof delegate === 'string') {
          var potentialElements = _toConsumableArray(this.context.element.querySelectorAll(delegate));

          targetElement = e.target.matches(delegate) ? e.target : $parent(e.target, delegate);
          hasMatch = potentialElements.indexOf(targetElement) >= 0;
        } else {
          var els = Array.isArray(delegate) || delegate instanceof NodeList ? _toConsumableArray(delegate) : [delegate];
          hasMatch = els.some(function (el) {
            if (el === e.target || el.contains(e.target)) {
              targetElement = el;
              return true;
            }

            return false;
          });
        }

        if (hasMatch) {
          this[this.getMethod(e.type)](e, targetElement);
          this.plugins.forEach(function (plugin) {
            plugin.handleEvent && plugin.handleEvent(_this3, e);
          });
        }
      } else {
        this[this.getMethod(e.type)](e);
        this.plugins.forEach(function (plugin) {
          plugin.handleEvent && plugin.handleEvent(_this3, e);
        });
      }
    }
  }, {
    key: "bindAll",
    value: function bindAll() {
      var _this4 = this;

      var events = this.constructor.events || [];
      events.forEach(function (type) {
        _this4._bindEvent(type);
      });
      this.plugins.forEach(function (plugin) {
        plugin.bindAll && plugin.bindAll(_this4, events);
      });
    }
  }, {
    key: "unbindAll",
    value: function unbindAll() {
      var _this5 = this;

      var events = this.constructor.events;
      events.forEach(function (type) {
        _this5._unbindEvent(type);
      });
      this.plugins.forEach(function (plugin) {
        plugin.unbindAll && plugin.unbindAll(_this5, events);
      });
    }
  }, {
    key: "bind",
    value: function bind(type) {
      this._bindEvent(type);
    }
  }, {
    key: "unbind",
    value: function unbind(type) {
      this._unbindEvent(type);
    }
  }, {
    key: "subscribe",
    value: function subscribe(slug) {
      return subscribers.add(this, slug);
    }
  }, {
    key: "emit",
    value: function emit() {
      for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
        args[_key] = arguments[_key];
      }

      // eslint-disable-line class-methods-use-this
      subscribers.emit.apply(subscribers, [this].concat(args));
    }
  }, {
    key: "unsubscribeAll",
    value: function unsubscribeAll() {
      subscribers.remove(this);
    }
  }], [{
    key: "getOptions",
    value: function getOptions(type) {
      var opts = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {
        capture: false
      };

      // https://github.com/WICG/EventListenerOptions/blob/gh-pages/explainer.md
      if (passiveEvents.includes(type)) {
        opts.passive = true;
      }

      return detectIt.passiveEvents === true ? opts : opts.capture;
    }
  }]);

  return Handler;
}();

==> kapla-2.1.4.tgz: package/lib/events/Handler.js <==
function _toConsumableArray(arr) { return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _nonIterableSpread(); }

function _nonIterableSpread() { throw new TypeError("Invalid attempt to spread non-iterable instance"); }

function _iterableToArray(iter) { if (Symbol.iterator in Object(iter) || Object.prototype.toString.call(iter) === "[object Arguments]") return Array.from(iter); }

function _arrayWithoutHoles(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = new Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } }

function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance"); }

function _iterableToArrayLimit(arr, i) { if (!(Symbol.iterator in Object(arr) || Object.prototype.toString.call(arr) === "[object Arguments]")) { return; } var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

import detectIt from 'detect-it';
import { ucfirst, lcfirst, $parent } from '../helpers';
import { customEvents, mixedEvents, passiveEvents, subscribers } from '../events';
export var Handler =
/*#__PURE__*/
function () {
  _createClass(Handler, null, [{
    key: "events",
    get: function get() {
      return this._events || Object.defineProperty(this, '_events', {
        value: Object.getOwnPropertyNames(this.prototype).filter(function (type) {
          return /^on/.test(type);
        }).map(function (type) {
          return lcfirst(type.slice(2));
        })
      })._events;
    }
  }]);

  function Handler(context) {
    _classCallCheck(this, Handler);

    this.context = context;
    this.plugins = context.module.application.plugins;
  }

  _createClass(Handler, [{
    key: "getMethod",
    value: function getMethod(eventName) {
      var name = eventName; // If part of mixed event, look for mixed event method
      // ex: mousenter -> onEnter ?

      if (mixedEvents.hasValue(eventName) && this.constructor.events.includes(mixedEvents.getKeysForValue(eventName)[0])) {
        var _mixedEvents$getKeysF = mixedEvents.getKeysForValue(eventName);

        var _mixedEvents$getKeysF2 = _slicedToArray(_mixedEvents$getKeysF, 1);

        name = _mixedEvents$getKeysF2[0];
      }

      var type = ucfirst(name);
      return "on".concat(type);
    }
  }, {
    key: "getCustomOptions",
    value: function getCustomOptions(type) {
      return this["options".concat(ucfirst(type))] || false;
    }
  }, {
    key: "getCategory",
    value: function getCategory(type) {
      // Custom event
      if (customEvents.getScope(type)) {
        return 'custom';
      } // Mixed event


      if (mixedEvents.hasKey(type)) {
        return 'mixed';
      } // Native event


      if (this[this.getMethod(type)]) {
        return 'native';
      }

      return false;
    }
  }, {
    key: "_bindEvent",
    value: function _bindEvent(type) {
      var _this = this;

      var category = this.getCategory(type);

      if (!category) {
        this.context.handleError(new Error(), "Unknown event type [".concat(type, "]"));
      }

      switch (category) {
        case 'custom':
          customEvents.bind(type, this, this.getCustomOptions(type));
          break;

        case 'mixed':
          mixedEvents.getValuesForKey(type).forEach(function (mixed) {
            _this.context.element.addEventListener(mixed, _this, Handler.getOptions(mixed));
          });
          break;

        case 'native':
        default:
          this.context.element.addEventListener(type, this, Handler.getOptions(type));
          break;
      }
    }
  }, {
    key: "_unbindEvent",
    value: function _unbindEvent(type) {
      var _this2 = this;

      var category = this.getCategory(type);

      if (!category) {
        this.context.handleError(new Error(), "Unknown event type [".concat(type, "]"));
      }

      switch (category) {
        case 'custom':
          customEvents.unbind(type, this);
          break;

        case 'mixed':
          mixedEvents.getValuesForKey(type).forEach(function (mixed) {
            _this2.context.element.removeEventListener(mixed, _this2, Handler.getOptions(mixed));
          });
          break;

        case 'native':
        default:
          this.context.element.removeEventListener(type, this, Handler.getOptions(type));
          break;
      }
    }
  }, {
    key: "handleEvent",
    value: function handleEvent(e) {
      var _this3 = this;

      // Get correct type (if mixed event) to check for delegate
      var type = mixedEvents.getKeysForValue(e.type)[0] || e.type;
      var delegate = this["delegate".concat(ucfirst(type))];

      if (delegate) {
        var hasMatch = false;
        var targetElement = null;

        if (typeof delegate === 'string') {
          var potentialElements = _toConsumableArray(this.context.element.querySelectorAll(delegate));

          targetElement = e.target.matches(delegate) ? e.target : $parent(e.target, delegate);
          hasMatch = potentialElements.indexOf(targetElement) >= 0;
        } else {
          var els = Array.isArray(delegate) || delegate instanceof NodeList ? _toConsumableArray(delegate) : [delegate];
          hasMatch = els.some(function (el) {
            if (el === e.target || el.contains(e.target)) {
              targetElement = el;
              return true;
            }

            return false;
          });
        }

        if (hasMatch) {
          this[this.getMethod(e.type)](e, targetElement);
          this.plugins.forEach(function (plugin) {
            plugin.handleEvent && plugin.handleEvent(_this3, e);
          });
        }
      } else {
        this[this.getMethod(e.type)](e);
        this.plugins.forEach(function (plugin) {
          plugin.handleEvent && plugin.handleEvent(_this3, e);
        });
      }
    }
  }, {
    key: "bindAll",
    value: function bindAll() {
      var _this4 = this;

      var events = this.constructor.events || [];
      events.forEach(function (type) {
        _this4._bindEvent(type);
      });
      this.plugins.forEach(function (plugin) {
        plugin.bindAll && plugin.bindAll(_this4, events);
      });
    }
  }, {
    key: "unbindAll",
    value: function unbindAll() {
      var _this5 = this;

      var events = this.constructor.events;
      events.forEach(function (type) {
        _this5._unbindEvent(type);
      });
      this.plugins.forEach(function (plugin) {
        plugin.unbindAll && plugin.unbindAll(_this5, events);
      });
    }
  }, {
    key: "bind",
    value: function bind(type) {
      this._bindEvent(type);
    }
  }, {
    key: "unbind",
    value: function unbind(type) {
      this._unbindEvent(type);
    }
  }, {
    key: "subscribe",
    value: function subscribe(slug) {
      return subscribers.add(this, slug);
    }
  }, {
    key: "emit",
    value: function emit() {
      for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
        args[_key] = arguments[_key];
      }

      // eslint-disable-line class-methods-use-this
      subscribers.emit.apply(subscribers, [this].concat(args));
    }
  }, {
    key: "unsubscribeAll",
    value: function unsubscribeAll() {
      subscribers.remove(this);
    }
  }], [{
    key: "getOptions",
    value: function getOptions(type) {
      var opts = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {
        capture: false
      };

      // https://github.com/WICG/EventListenerOptions/blob/gh-pages/explainer.md
      if (passiveEvents.includes(type)) {
        opts.passive = true;
      }

      return detectIt.passiveEvents === true ? opts : opts.capture;
    }
  }]);

  return Handler;
}();
